@@ -35,14 +35,14 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-pref("general.useragent.extra.thunderbird", "Thunderbird/1.5.0.9");
-//@line 39 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/app/profile/all-thunderbird.js"
+pref("general.useragent.extra.thunderbird", "Thunderbird/1.5.0.10");
+//@line 39 "/usr/obj/ports/mozilla-thunderbird-1.5.0.10/mozilla/mail/app/profile/all-thunderbird.js"
 
 pref("general.useragent.locale", "en-US");
-//@line 41 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 41 "/usr/obj/ports/mozilla-thunderbird-1.5.0.10/mozilla/mail/app/profile/all-thunderbird.js"
 pref("general.skins.selectedSkin", "classic/1.0");
 
-//@line 47 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 47 "/usr/obj/ports/mozilla-thunderbird-1.5.0.10/mozilla/mail/app/profile/all-thunderbird.js"
 
 pref("update.app.enabled", true); // Whether or not app updates are enabled 
 pref("update.app.url", "chrome://mozapps/locale/update/update.properties");	
@@ -160,11 +160,11 @@ pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
 pref("mail.phishing.detection.enabled", true); // enable / disable phishing detection for link clicks
 pref("mail.spellcheck.inline", true);
 
-//@line 167 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 167 "/usr/obj/ports/mozilla-thunderbird-1.5.0.10/mozilla/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.instantApply", true);
-//@line 172 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 172 "/usr/obj/ports/mozilla-thunderbird-1.5.0.10/mozilla/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 174 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 174 "/usr/obj/ports/mozilla-thunderbird-1.5.0.10/mozilla/mail/app/profile/all-thunderbird.js"
 
 /////////////////////////////////////////////////////////////////
 // Overrides of the seamonkey suite mailnews.js prefs
@@ -243,6 +243,7 @@ pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/in
 pref("signon.rememberSignons",              true);
 pref("signon.expireMasterPassword",         false);
 pref("signon.SignonFileName",               "signons.txt");
+pref("signon.SignonFileName2",              "signons2.txt");
 
 pref("browser.hiddenWindowChromeURL", "chrome://messenger/content/hiddenWindow.xul");
 pref("network.search.url","http://cgi.netscape.com/cgi-bin/url_search.cgi?search=");
@@ -434,11 +435,11 @@ pref("privacy.popups.sound_enabled",              true);
 pref("privacy.popups.sound_url",                  "");
 pref("privacy.popups.statusbar_icon_enabled",     true);
 
-//@line 445 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 446 "/usr/obj/ports/mozilla-thunderbird-1.5.0.10/mozilla/mail/app/profile/all-thunderbird.js"
 // For the download dialog
 pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", false);
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 450 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9p1/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 451 "/usr/obj/ports/mozilla-thunderbird-1.5.0.10/mozilla/mail/app/profile/all-thunderbird.js"
 
 // prevent status-bar spoofing even if people are foolish enough to turn on JS
 pref("dom.disable_window_status_change",          true);
