@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/ports/mozilla-thunderbird-1.5.0.9/mozilla/mail/extensions/newsblog/content/Feed.js"
+//@line 37 "/usr/obj/ports/mozilla-thunderbird-1.5.0.10/mozilla/mail/extensions/newsblog/content/Feed.js"
 
 
 // error codes used to inform the consumer about attempts to download a feed
@@ -32,7 +32,7 @@ var FeedCache =
   normalizeHost: function (aUrl)
   {
     var ioService = Components.classes["@mozilla.org/network/io-service;1"].
-                    createInstance(Components.interfaces.nsIIOService);
+                    getService(Components.interfaces.nsIIOService);
     var normalizedUrl = ioService.newURI(aUrl, null, null);
     normalizedUrl.host = normalizedUrl.host.toLowerCase();
     return normalizedUrl.spec;
